from pathlib import Path

import requests

from config import DB_PATH, tCOMMON_TOKEN, tCOMMON_URL_INTERNAL

config = requests.get(f"{tCOMMON_URL_INTERNAL}/api/initialize/", params={
    "token": tCOMMON_TOKEN
}, allow_redirects=False).json()

if not config["success"]:
    raise ImportError("tCommon token doesn't match")

if not config["services"]["blog"]:
    raise ImportError("tBlog isn't registered in tCommon")

DEBUG = config["debug"]
SECRET_KEY = config["services"]["blog"]["token"]

BASE_DIR = Path(__file__).resolve().parent.parent

STATIC_DIR = BASE_DIR / "tblog/static"
ALLOWED_HOSTS = ["*"]
CSRF_TRUSTED_ORIGINS = [config["services"]["blog"]["url"]["pub"]]

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "tblog.apps.DBConfig"
]

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware"
]

ROOT_URLCONF = "tblog.urls"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [
            BASE_DIR / "tblog/templates"
        ],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]

WSGI_APPLICATION = "tblog.wsgi.application"

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": BASE_DIR / DB_PATH,
    }
}

AUTH_PASSWORD_VALIDATORS = []
LANGUAGE_CODE = "en-us"
TIME_ZONE = "UTC"
USE_I18N = True
USE_TZ = True
DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"
